#ifndef NET_LOAD_HPP
#define NET_LOAD_HPP

#include <boost/extension/extension.hpp>
#include <boost/extension/factory.hpp>
#include <boost/extension/type_map.hpp>
#include <boost/property_tree/ptree.hpp>
#include <boost/property_tree/xml_parser.hpp>

#include <sys/utsname.h>
#include <syslog.h>

#include <plugins/plugin.hpp>

#include <glibtop.h>
#include <glibtop/netlist.h>
#include <glibtop/netload.h>
#include <iostream>
#include <arpa/inet.h>

#include <ndds/ndds_cpp.h>
#include "net_load_dds.h"
#include "net_load_ddsSupport.h"


class net_load : public plugin {
public:
  net_load(std::string plugin_id);
  virtual void publish_information(void);
  virtual void clean_dds_stuff(void);
  
private:
  host_info hi_;
  glibtop_netlist buf_;
  glibtop_netload netload_;
  char** devices_;
  struct in_addr addr_, subnet_;
  //DDS Stuff
  DDSDomainParticipant *participant_;
  DDSPublisher *publisher_;
  DDSTopic *topic_;
  DDSDataWriter *writer_;
  netloadDataWriter * netload_writer_;
  netload *instance_;
  DDS_ReturnCode_t retcode_;
  DDS_InstanceHandle_t instance_handle_;
  const char *type_name_;
  DDS_Duration_t send_period_;
  int domain_id_;
  std::string topic_name_;
  std::string qos_profile_;
  std::string qos_library_;
  std::string plugin_id_;
};

BOOST_EXTENSION_TYPE_MAP_FUNCTION
{
  using namespace boost::extensions;
  std::map<std::string, factory<plugin, std::string> > &plugin_factories(types.get());
  plugin_factories["net_load"].set<net_load>();
}


#endif //NET_LOAD_HPP

